@@ -431,6 +431,9 @@ class oofun(OOFun):
 
     # overload "a/b"
     def __div__(self, other):
+        if isinstance(other, ndarray) and other.dtype == object:
+            from ooarray import ooarray
+            return other.view(ooarray).__rdiv__(self)
         if isinstance(other, OOArray):
             return other.__rdiv__(self)
         if isinstance(other, list): other = asarray(other)
@@ -600,6 +603,9 @@ class oofun(OOFun):
     __rmul__ = __mul__
 
     def __pow__(self, other):
+        if isinstance(other, ndarray) and other.dtype == object:
+            from ooarray import ooarray
+            return other.view(ooarray).__rpow__(self)
         if isinstance(other, OOArray):
             return other.__rpow__(self)
 
